# MIPAS (2007) data files

The *MIPAS reference atmospheres* are documented in the following published 
article:

Remedios, J. J., R. J. Leigh, A. M. Waterfall, D. P. Moore, H. Sembhi, I. Parkes, J. Greenhough, M. P. Chipperfield, and D. Hauglustaine. 2007. ‘MIPAS Reference Atmospheres and Comparisons to V4.61/V4.62 MIPAS Level 2 Geophysical Data Sets’. Atmospheric Chemistry and Physics Discussions 7 (4): 9973–10017. [https://doi.org/10.5194/acpd-7-9973-2007](https://doi.org/10.5194/acpd-7-9973-2007).


## Downloaded data

Data files were downloaded on 2022-12-12 from:
https://web.archive.org/web/20161112234010/http://eodg.atm.ox.ac.uk/RFM/atm/.

Remedios et al. (2007) indicate (page 9982) that the data files for the
*MIPAS reference atmospheres* are available for download at
http://www.atm.ox.ac.uk/RFM/rfm/downloads.html.
However, as of 2022-12-12, the URL cannot be reached and returns the error:

```
Not Found

The requested URL was not found on this server.
```

Thus, the above URL was put into the Wayback machine at https://web.archive.org/
and the oldest snapshot (from 2016-06-06,
https://web.archive.org/web/20160706124313/https://eodg.atm.ox.ac.uk/RFM/rfm_downloads.html)
was used to download the files `day.atm`, `ngt.atm`, `win.atm`, `sum.atm`,
and `equ.atm`, `extra.atm` under `Atmospheric Profiles (.atm files)`.


## Version

It is not clear whether the corresponding data files correspond to version 3.0
or version 3.1 of the MIPAS reference atmospheres.
The downloaded data files headers mention:
```
! 03-JAN-2001  JJR  VERSION 3.0
```

However, J. J. Remedios et al. (2007) pages 9981-9982 indicate that:

> Current data versions are V3.1 for the MIPAS standard atmospheres
(available for download at http://www.atm.ox.ac.uk/RFM/rfm/downloads.html).